# Hibachi
**Hibachi** is a Python package that implements feature selection methods for
PyTorch.

## Installation
Run the following command:

```
pip install hibachi
```

## References
```
@incollection {
    NIPS2017_7270,
    title = {Kernel Feature Selection via Conditional Covariance Minimization},
    author = {Chen, Jianbo and Stern, Mitchell and Wainwright, Martin J and
        Jordan, Michael I},
    booktitle = {Advances in Neural Information Processing Systems 30},
    editor = {I. Guyon and U. V. Luxburg and S. Bengio and H. Wallach and R.
        Fergus and S. Vishwanathan and R. Garnett},
    pages = {6949--6958},
    year = {2017},
    publisher = {Curran Associates, Inc.},
    url = {http://papers.nips.cc/paper/7270-kernel-feature-selection-via-conditional-covariance-minimization.pdf}
}
```
